@@ -41,14 +41,13 @@ MainWidget::MainWidget(QWidget *parent) :
     m_statuslbl.setFont(f);
 
     // table
-    m_statuslbl.show();
-
-    this->setLayout(&m_layout);
     m_layout.addWidget(&m_statuslbl);
     m_layout.addWidget(m_scoretbl);
+    this->setLayout(&m_layout);
+    m_statuslbl.show();
 
     connect(m_settingsdlg, SIGNAL(accepted()),
-            this, SLOT(update()));
+            this, SLOT(onSettingsAccepted()));
 
     connect(m_backend, SIGNAL(updateFinished(int)),
             this, SLOT(onBackendUpdateFinished(int)));
@@ -74,7 +73,7 @@ void MainWidget::mousePressEvent(QMouseEvent* event)
     }
 }
 
-void MainWidget::update(void)
+void MainWidget::onSettingsAccepted()
 {
     m_backend->selectLeague(m_settings.value("League", "1. Bundesliga").toString());
 }
@@ -84,15 +83,13 @@ void MainWidget::onBackendUpdateStarted()
 
 }
 
-void MainWidget::onBackendUpdateFinished(int error)
+void MainWidget::onBackendUpdateFinished(int)
 {
-    if (error > 0) {
-        m_statuslbl.setText(tr("Error occured\nRetry pending..."));
-        m_statuslbl.show();
-        m_scoretbl->hide();
-    } else {
-        m_scoretbl->show();
+    if (m_statuslbl.isHidden() == false) {
+        this->hide();
         m_statuslbl.hide();
+        m_scoretbl->show();
+        this->show();
     }
 }
 
@@ -108,14 +105,18 @@ void MainWidget::onMatchAdded(Match* match) {
 
 void MainWidget::onScoreChange()
 {
-    m_mediaObject_tor->play();
-    qDebug() << "Playing sound: tor";
+    if (m_settings.value("Sounds", false).toBool()) {
+        m_mediaObject_tor->play();
+        qDebug() << "Playing sound: tor";
+    }
 }
 
 void MainWidget::onMatchStateChanged(Match::MatchState)
 {
-    m_mediaObject_pfeife->play();
-    qDebug() << "Playing sound: trillerpfeife";
+    if (m_settings.value("Sounds", false).toBool()) {
+        m_mediaObject_pfeife->play();
+        qDebug() << "Playing sound: trillerpfeife";
+    }
 }
 
 void MainWidget::showSettingsDialog()
