@@ -42,16 +42,21 @@ QSize ScoreTable::sizeHint() const
     QSize s;
     int maxrows = 9;
 
-    for (int i = 0; i < horizontalHeader()->count(); i++) {
-        s.setWidth(s.width() + horizontalHeader()->sectionSize(i));
-    }
+    if (verticalHeader()->count() > 0) {
+        for (int i = 0; i < horizontalHeader()->count(); i++) {
+            s.setWidth(s.width() + horizontalHeader()->sectionSize(i));
+        }
 
-    for (int i = 0; i < verticalHeader()->count(), i < maxrows; i++) {
-        s.setHeight(s.height() + verticalHeader()->sectionSize(i));
+        for (int i = 0; i < verticalHeader()->count() && i < maxrows; i++) {
+            s.setHeight(s.height() + verticalHeader()->sectionSize(i));
+        }
+        // add missing few pixels (from borders mabye?)
+        // TODO: find better solution!
+        s.setHeight(s.height() + 2);
+    } else {
+        s.setHeight(200);
+        s.setWidth(400);
     }
-    // add missing few pixels (from borders mabye?)
-    // TODO: find better solution!
-    s.setHeight(s.height() + 2);
 
     return s;
 }
