@@ -22,7 +22,7 @@ protected:
     void closeEvent(QCloseEvent);
 
 protected slots:
-    void onLeagueSelected(QAbstractButton* button);
+    void onDlgAccepted();
 
 private:
     Ui::SettingsDialog *ui;
